@@ -36,8 +36,8 @@ struct passwd {
     pw_shell: *const libc::c_char,
 }
 
-// Used on BSD family targets
-#[cfg(any(target_os = "macos", target_os = "freebsd", target_os = "openbsd", target_os = "netbsd"))]
+// Used on MacOS and FreeBSD
+#[cfg(any(target_os = "macos", target_os = "freebsd"))]
 #[repr(C)]
 #[allow(dead_code)]
 struct passwd {
@@ -54,6 +54,23 @@ struct passwd {
     pw_fields: libc::c_int,
 }
 
+// Used on the other two supported BSDs
+#[cfg(any(target_os = "openbsd", target_os = "netbsd"))]
+#[repr(C)]
+#[allow(dead_code)]
+struct passwd {
+    pw_name: *const libc::c_char,
+    pw_passwd: *const libc::c_char,
+    pw_uid: libc::uid_t,
+    pw_gid: libc::gid_t,
+    pw_change: libc::time_t,
+    pw_class: *const libc::c_char,
+    pw_gecos: *const libc::c_char,
+    pw_dir: *const libc::c_char,
+    pw_shell: *const libc::c_char,
+    pw_expire: libc::time_t,
+}
+
 #[allow(dead_code)]
 extern "C" {
     fn getgrnam(name: *const libc::c_char) -> *const group;
